@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,7 +12,7 @@
 """
 
 
-from traits.api import Bool, Str
+from traits.api import Bool, HasTraits, Str
 
 
 from pyface.i_dialog import IDialog
@@ -42,7 +42,7 @@ class IDirectoryDialog(IDialog):
     path = Str()
 
 
-class MDirectoryDialog(object):
+class MDirectoryDialog(HasTraits):
     """ The mixin class that contains common code for toolkit specific
     implementations of the IDirectoryDialog interface.
     """
