@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -10,7 +10,7 @@
 
 
 from pyface.action.api import Action, ActionItem, Group
-from traits.api import Any, List, Instance, Property, Str, on_trait_change
+from traits.api import Any, List, Instance, Property, Str, observe
 
 
 from pyface.tasks.task import Task
@@ -24,16 +24,17 @@ class TaskToggleAction(Action):
     # 'Action' interface ---------------------------------------------------
 
     #: The user-visible name of the action, matches the task name.
-    name = Property(Str, depends_on="task.name")
+    name = Property(Str, observe="task.name")
 
     #: The action is a toggle menu item.
     style = "toggle"
 
     #: The tooltip to display for the menu item.
-    tooltip = Property(Str, depends_on="name")
+    tooltip = Property(Str, observe="name")
 
-    # 'TaskActivateAction' interface ---------------------------------------
+    # 'TaskToggleAction' interface -----------------------------------------
 
+    #: The Task with which the action is associated.
     task = Instance(Task)
 
     # ------------------------------------------------------------------------
@@ -62,10 +63,10 @@ class TaskToggleAction(Action):
         return self.task.name
 
     def _get_tooltip(self):
-        return u"Switch to the %s task." % self.name
+        return "Switch to the %s task." % self.name
 
-    @on_trait_change("task.window.active_task")
-    def _update_checked(self):
+    @observe("task.window.active_task")
+    def _update_checked(self, event):
         if self.task:
             window = self.task.window
             self.checked = (
@@ -82,12 +83,12 @@ class TaskToggleGroup(Group):
     id = "TaskToggleGroup"
     items = List()
 
-    # 'TaskChangeMenuManager' interface ------------------------------------
+    # 'TaskToggleGroup' interface ------------------------------------------
 
-    # The ActionManager to which the group belongs.
+    #: The ActionManager to which the group belongs.
     manager = Any()
 
-    # The window that contains the group.
+    #: The window that contains the group.
     window = Instance(TaskWindow)
 
     # ------------------------------------------------------------------------
@@ -104,7 +105,7 @@ class TaskToggleGroup(Group):
             ]
         return items
 
-    def _rebuild(self):
+    def _rebuild(self, event):
         # Clear out the old group, then build the new one.
         self.destroy()
         self.items = self._get_items()
@@ -115,7 +116,7 @@ class TaskToggleGroup(Group):
     # Trait initializers ---------------------------------------------------
 
     def _items_default(self):
-        self.window.on_trait_change(self._rebuild, "tasks[]")
+        self.window.observe(self._rebuild, "tasks.items")
         return self._get_items()
 
     def _manager_default(self):
