@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -13,8 +13,10 @@ import os
 import unittest
 
 from traits.api import DefaultValue, HasTraits, TraitError
-from traits.testing.unittest_tools import UnittestTools
+from traits.testing.optional_dependencies import numpy as np, requires_numpy
+from traits.testing.api import UnittestTools
 
+from ..color import Color
 from ..i_image_resource import IImageResource
 from ..image_resource import ImageResource
 from ..ui_traits import (
@@ -23,6 +25,7 @@ from ..ui_traits import (
     HasMargin,
     Image,
     Margin,
+    PyfaceColor,
     image_resource_cache,
     image_bitmap_cache,
 )
@@ -36,6 +39,11 @@ class ImageClass(HasTraits):
     image = Image
 
 
+class ColorClass(HasTraits):
+
+    color = PyfaceColor()
+
+
 class HasMarginClass(HasTraits):
 
     margin = HasMargin
@@ -125,6 +133,194 @@ class TestMargin(unittest.TestCase):
         self.assertEqual(margin.right, 2)
 
 
+class TestPyfaceColor(unittest.TestCase):
+
+    def test_init(self):
+        trait = PyfaceColor()
+        self.assertEqual(trait.default_value, (Color, (), {}))
+        self.assertEqual(
+            trait.default_value_type,
+            DefaultValue.callable_and_args,
+        )
+
+    def test_init_name(self):
+        trait = PyfaceColor("rebeccapurple")
+        self.assertEqual(
+            trait.default_value,
+            (Color, (), {'rgba': (0.4, 0.2, 0.6, 1.0)})
+        )
+
+    def test_init_hex(self):
+        trait = PyfaceColor("#663399ff")
+        self.assertEqual(
+            trait.default_value,
+            (Color, (), {'rgba': (0.4, 0.2, 0.6, 1.0)})
+        )
+
+    def test_init_color(self):
+        trait = PyfaceColor(Color(rgba=(0.4, 0.2, 0.6, 1.0)))
+        self.assertEqual(
+            trait.default_value,
+            (Color, (), {'rgba': (0.4, 0.2, 0.6, 1.0)})
+        )
+
+    def test_init_tuple(self):
+        trait = PyfaceColor((0.4, 0.2, 0.6, 1.0))
+        self.assertEqual(
+            trait.default_value,
+            (Color, (), {'rgba': (0.4, 0.2, 0.6, 1.0)})
+        )
+
+    def test_init_list(self):
+        trait = PyfaceColor([0.4, 0.2, 0.6, 1.0])
+        self.assertEqual(
+            trait.default_value,
+            (Color, (), {'rgba': (0.4, 0.2, 0.6, 1.0)})
+        )
+
+    @requires_numpy
+    def test_init_array(self):
+        trait = PyfaceColor(np.array([0.4, 0.2, 0.6, 1.0]))
+        self.assertEqual(
+            trait.default_value,
+            (Color, (), {'rgba': (0.4, 0.2, 0.6, 1.0)})
+        )
+
+    @requires_numpy
+    def test_init_array_structured_dtype(self):
+        """ Test if "typical" RGBA structured array value works. """
+        arr = np.array(
+            [(0.4, 0.2, 0.6, 1.0)],
+            dtype=np.dtype([
+                ('red', float),
+                ('green', float),
+                ('blue', float),
+                ('alpha', float),
+            ]),
+        )
+        trait = PyfaceColor(arr[0])
+        self.assertEqual(
+            trait.default_value,
+            (Color, (), {'rgba': (0.4, 0.2, 0.6, 1.0)})
+        )
+
+    def test_init_invalid(self):
+        with self.assertRaises(TraitError):
+            PyfaceColor((0.4, 0.2))
+
+    def test_validate_color(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        trait = PyfaceColor()
+        validated = trait.validate(None, None, color)
+        self.assertIs(
+            validated, color
+        )
+
+    def test_validate_name(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        trait = PyfaceColor()
+        validated = trait.validate(None, None, "rebeccapurple")
+        self.assertEqual(
+            validated, color
+        )
+
+    def test_validate_hex(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        trait = PyfaceColor()
+        validated = trait.validate(None, None, "#663399ff")
+        self.assertEqual(
+            validated, color
+        )
+
+    def test_validate_tuple(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 0.8))
+        trait = PyfaceColor()
+        validated = trait.validate(None, None, (0.4, 0.2, 0.6, 0.8))
+        self.assertEqual(
+            validated, color
+        )
+
+    def test_validate_list(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 0.8))
+        trait = PyfaceColor()
+        validated = trait.validate(None, None, [0.4, 0.2, 0.6, 0.8])
+        self.assertEqual(
+            validated, color
+        )
+
+    def test_validate_rgb_list(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        trait = PyfaceColor()
+        validated = trait.validate(None, None, [0.4, 0.2, 0.6])
+        self.assertEqual(
+            validated, color
+        )
+
+    def test_validate_bad_string(self):
+        trait = PyfaceColor()
+        with self.assertRaises(TraitError):
+            trait.validate(None, None, "not a color")
+
+    def test_validate_bad_object(self):
+        trait = PyfaceColor()
+        with self.assertRaises(TraitError):
+            trait.validate(None, None, object())
+
+    def test_info(self):
+        trait = PyfaceColor()
+        self.assertIsInstance(trait.info(), str)
+
+    def test_default_trait(self):
+        color_class = ColorClass()
+        self.assertEqual(color_class.color, Color())
+
+    def test_set_color(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        color_class = ColorClass(color=color)
+        self.assertIs(color_class.color, color)
+
+    def test_set_name(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        color_class = ColorClass(color="rebeccapurple")
+        self.assertEqual(color_class.color, color)
+
+    def test_set_hex(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        color_class = ColorClass(color="#663399ff")
+        self.assertEqual(color_class.color, color)
+
+    def test_set_tuple(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        color_class = ColorClass(color=(0.4, 0.2, 0.6, 1.0))
+        self.assertEqual(color_class.color, color)
+
+    def test_set_list(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        color_class = ColorClass(color=[0.4, 0.2, 0.6, 1.0])
+        self.assertEqual(color_class.color, color)
+
+    @requires_numpy
+    def test_set_array(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        color_class = ColorClass(color=np.array([0.4, 0.2, 0.6, 1.0]))
+        self.assertEqual(color_class.color, color)
+
+    @requires_numpy
+    def test_set_structured_dtype(self):
+        color = Color(rgba=(0.4, 0.2, 0.6, 1.0))
+        arr = np.array(
+            [(0.4, 0.2, 0.6, 1.0)],
+            dtype=np.dtype([
+                ('red', float),
+                ('green', float),
+                ('blue', float),
+                ('alpha', float),
+            ]),
+        )
+        color_class = ColorClass(color=arr[0])
+        self.assertEqual(color_class.color, color)
+
+
 class TestHasMargin(unittest.TestCase, UnittestTools):
     def test_defaults(self):
         has_margin = HasMarginClass()
