@@ -1,10 +1,11 @@
-# Copyright (c) 2005-18, Enthought, Inc.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 #
 # Author: Enthought, Inc.
@@ -25,7 +26,9 @@ class DoLaterTimer(Timer):
 
     def __init__(self, interval, callable, args, kw_args):
         # Adapt the old DoLaterTimer initializer to the Timer initializer.
-        super(DoLaterTimer, self).__init__(interval, callable, *args, **kw_args)
+        super(DoLaterTimer, self).__init__(
+            interval, callable, *args, **kw_args
+        )
 
 
 def do_later(callable, *args, **kwargs):
@@ -35,14 +38,11 @@ def do_later(callable, *args, **kwargs):
     ----------
     callable : callable
         The callable to call in 50ms time.
-    *args, **kwargs :
+    *args, \**kwargs : tuple, dict
         Arguments to be passed through to the callable.
     """
     return CallbackTimer.single_shot(
-        interval=0.05,
-        callback=callable,
-        args=args,
-        kwargs=kwargs,
+        interval=0.05, callback=callable, args=args, kwargs=kwargs
     )
 
 
@@ -55,12 +55,12 @@ def do_after(interval, callable, *args, **kwargs):
         The time interval in milliseconds to wait before calling.
     callable : callable
         The callable to call.
-    *args, **kwargs :
+    \*args
+        Positional arguments to be passed through to the callable.
+    \*\*kwargs
+        Keyword arguments to be passed through to the callable.
         Arguments to be passed through to the callable.
     """
     return CallbackTimer.single_shot(
-        interval=interval / 1000.0,
-        callback=callable,
-        args=args,
-        kwargs=kwargs,
+        interval=interval / 1000.0, callback=callable, args=args, kwargs=kwargs
     )
