@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -71,7 +71,7 @@ def get_tokens_unprocessed(self, text, stack=("root",)):
                     pos += 1
                     statestack = ["root"]
                     statetokens = tokendefs["root"]
-                    yield pos, Text, u"\n"
+                    yield pos, Text, "\n"
                     continue
                 yield pos, Error, text[pos]
                 pos += 1
@@ -192,6 +192,8 @@ class PygmentsHighlighter(QtGui.QSyntaxHighlighter):
         if token in self._formats:
             return self._formats[token]
         result = None
+        while not self._style.styles_token(token):
+            token = token.parent
         for key, value in self._style.style_for_token(token).items():
             if value:
                 if result is None:
