@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -136,6 +136,11 @@ class ConsoleWidget(QtGui.QWidget):
         """
         super(ConsoleWidget, self).__init__(parent)
 
+        # A list of connected Qt signals to be removed before destruction.
+        # First item in the tuple is the Qt signal. The second item is the
+        # event handler.
+        self._connections_to_remove = []
+
         # Create the layout and underlying text widget.
         layout = QtGui.QStackedLayout(self)
         layout.setContentsMargins(0, 0, 0, 0)
@@ -193,6 +198,7 @@ class ConsoleWidget(QtGui.QWidget):
             printkey = "Ctrl+Shift+P"
         action.setShortcut(printkey)
         action.triggered.connect(self.print_)
+        self._connections_to_remove.append((action.triggered, self.print_))
         self.addAction(action)
         self._print_action = action
 
@@ -200,6 +206,7 @@ class ConsoleWidget(QtGui.QWidget):
         action.setEnabled(self.can_export())
         action.setShortcut(QtGui.QKeySequence.Save)
         action.triggered.connect(self.export)
+        self._connections_to_remove.append((action.triggered, self.export))
         self.addAction(action)
         self._export_action = action
 
@@ -207,6 +214,7 @@ class ConsoleWidget(QtGui.QWidget):
         action.setEnabled(True)
         action.setShortcut(QtGui.QKeySequence.SelectAll)
         action.triggered.connect(self.select_all)
+        self._connections_to_remove.append((action.triggered, self.select_all))
         self.addAction(action)
         self._select_all_action = action
 
@@ -304,6 +312,11 @@ class ConsoleWidget(QtGui.QWidget):
 
         return super(ConsoleWidget, self).eventFilter(obj, event)
 
+    def _remove_event_listeners(self):
+        while self._connections_to_remove:
+            signal, handler = self._connections_to_remove.pop()
+            signal.disconnect(handler)
+
     # ---------------------------------------------------------------------------
     # 'QWidget' interface
     # ---------------------------------------------------------------------------
@@ -857,12 +870,12 @@ class ConsoleWidget(QtGui.QWidget):
             Enter/Return key press, 'interactive' is True; otherwise, it is
             False.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _execute(self, source, hidden):
         """ Execute 'source'. If 'hidden', do not show any output.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _prompt_started_hook(self):
         """ Called immediately after a new prompt is displayed.
@@ -1056,12 +1069,28 @@ class ConsoleWidget(QtGui.QWidget):
 
         # Connect signals.
         control.cursorPositionChanged.connect(self._cursor_position_changed)
+        self._connections_to_remove.append(
+            (control.cursorPositionChanged, self._cursor_position_changed)
+        )
         control.customContextMenuRequested.connect(
             self._custom_context_menu_requested
         )
+        self._connections_to_remove.append(
+            (control.customContextMenuRequested,
+             self._custom_context_menu_requested)
+        )
         control.copyAvailable.connect(self.copy_available)
+        self._connections_to_remove.append(
+            (control.copyAvailable, self.copy_available)
+        )
         control.redoAvailable.connect(self.redo_available)
+        self._connections_to_remove.append(
+            (control.redoAvailable, self.redo_available)
+        )
         control.undoAvailable.connect(self.undo_available)
+        self._connections_to_remove.append(
+            (control.undoAvailable, self.undo_available)
+        )
 
         # Hijack the document size change signal to prevent Qt from adjusting
         # the viewport's scrollbar. We are relying on an implementation detail
@@ -1070,6 +1099,8 @@ class ConsoleWidget(QtGui.QWidget):
         layout = control.document().documentLayout()
         layout.documentSizeChanged.disconnect()
         layout.documentSizeChanged.connect(self._adjust_scrollbars)
+        # The document layout doesn't stay the same therefore its signal is
+        # not explicitly disconnected on destruction
 
         # Configure the control.
         control.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
