@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,7 +14,9 @@ import time
 
 from pyface.qt import QtGui, QtCore
 
-from traits.api import Bool, Instance, Int, Str, provides
+from traits.api import (
+    Any, Bool, Callable, Instance, Int, List, Str, provides, Tuple
+)
 
 from pyface.i_progress_dialog import IProgressDialog, MProgressDialog
 from .window import Window
@@ -81,6 +83,13 @@ class ProgressDialog(MProgressDialog, Window):
     #: The widget showing the estimated time remaining
     _remaining_control = Instance(QtGui.QLabel)
 
+    # Private interface ---------------------------------------------------#
+
+    #: A list of connected Qt signals to be removed before destruction.
+    #: First item in the tuple is the Qt signal. The second item is the event
+    #: handler.
+    _connections_to_remove = List(Tuple(Any, Callable))
+
     # -------------------------------------------------------------------------
     # IWindow Interface
     # -------------------------------------------------------------------------
@@ -97,6 +106,17 @@ class ProgressDialog(MProgressDialog, Window):
 
         super(ProgressDialog, self).close()
 
+    # -------------------------------------------------------------------------
+    # 'IWidget' interface.
+    # -------------------------------------------------------------------------
+
+    def destroy(self):
+        while self._connections_to_remove:
+            signal, handler = self._connections_to_remove.pop()
+            signal.disconnect(handler)
+
+        super(ProgressDialog, self).destroy()
+
     # -------------------------------------------------------------------------
     # IProgressDialog Interface
     # -------------------------------------------------------------------------
@@ -182,8 +202,14 @@ class ProgressDialog(MProgressDialog, Window):
 
         if self.can_cancel:
             buttons.rejected.connect(dialog.reject)
+            self._connections_to_remove.append(
+                (buttons.rejected, dialog.reject)
+            )
         if self.can_ok:
             buttons.accepted.connect(dialog.accept)
+            self._connections_to_remove.append(
+                (buttons.accepted, dialog.accept)
+            )
 
         layout.addWidget(buttons)
 
@@ -227,7 +253,7 @@ class ProgressDialog(MProgressDialog, Window):
         if not self.show_percent:
             return
 
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _create_timer(self, dialog, layout):
         if not self.show_time:
