@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -118,9 +118,11 @@ class PythonShell(MPythonShell, Widget):
     def _remove_event_listeners(self):
         if self.control is not None:
             # Disconnect signals for events.
-            self.control.executed.connect(self._on_command_executed)
+            self.control.executed.disconnect(self._on_command_executed)
             self._event_filter.signal.disconnect(self._on_obj_drop)
 
+            self.control._remove_event_listeners()
+
         super(PythonShell, self)._remove_event_listeners()
 
     def __event_filter_default(self):
@@ -200,6 +202,15 @@ class PythonWidget(HistoryConsoleWidget):
         # Display the banner and initial prompt.
         self.reset()
 
+    def _remove_event_listeners(self):
+        self.font_changed.disconnect(self._call_tip_widget.setFont)
+        document = self._control.document()
+        document.contentsChange.disconnect(self._document_contents_change)
+
+        self._bracket_matcher._remove_event_listeners()
+
+        super(PythonWidget, self)._remove_event_listeners()
+
     # --------------------------------------------------------------------------
     # file-like object interface
     # --------------------------------------------------------------------------
