@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -20,7 +20,7 @@ import logging
 from pyface.qt import QtCore, QtGui
 
 
-from traits.api import Instance, on_trait_change
+from traits.api import Instance, observe
 
 
 from pyface.message_dialog import error
@@ -328,26 +328,29 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             if editor.control == control:
                 editor.name = str(title)
 
-    def _qt4_editor_tab_spinner(self, editor, name, new):
+    def _qt4_editor_tab_spinner(self, event):
+        editor = event.object
+
         # Do we need to do this verification?
         tw, tidx = self._qt4_editor_area._tab_widget(editor.control)
 
-        if new:
+        if event.new:
             tw.show_button(tidx)
         else:
             tw.hide_button(tidx)
 
-        if not new and not editor == self.window.active_editor:
+        if not event.new and not editor == self.window.active_editor:
             self._qt4_editor_area.setTabTextColor(
                 editor.control, QtCore.Qt.red
             )
 
-    @on_trait_change("window:active_editor")
-    def _qt4_active_editor_changed(self, old, new):
+    @observe("window:active_editor")
+    def _qt4_active_editor_changed(self, event):
         """ Handle change of active editor """
         # Reset tab title to foreground color
-        if new is not None:
-            self._qt4_editor_area.setTabTextColor(new.control)
+        editor = event.new 
+        if editor is not None:
+            self._qt4_editor_area.setTabTextColor(editor.control)
 
     def _qt4_view_focus_changed(self, old, new):
         """ Handle the change of focus for a view. """
@@ -442,14 +445,15 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             editor.control = editor.create_control(self.window.control)
             editor.control.setObjectName(editor.id)
 
-            editor.on_trait_change(self._qt4_editor_tab_spinner, "_loading")
+            editor.observe(self._qt4_editor_tab_spinner, "_loading")
 
             self.editor_opened = editor
 
-        def on_name_changed(editor, trait_name, old, new):
+        def on_name_changed(event):
+            editor = event.object
             self._qt4_editor_area.setWidgetTitle(editor.control, editor.name)
 
-        editor.on_trait_change(on_name_changed, "name")
+        editor.observe(on_name_changed, "name")
 
         self._qt4_monitor(editor.control)
 
@@ -524,10 +528,10 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             # Save the dock window.
             view._qt4_dock = dw
 
-            def on_name_changed():
+            def on_name_changed(event):
                 view._qt4_dock.setWindowTitle(view.name)
 
-            view.on_trait_change(on_name_changed, "name")
+            view.observe(on_name_changed, "name")
 
         # Make sure the view control exists.
         if view.control is None:
