@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -169,12 +169,12 @@ class MainWindowLayout(HasTraits):
     def _get_dock_widget(self, pane):
         """ Returns the QDockWidget associated with a PaneItem.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _get_pane(self, dock_widget):
         """ Returns a PaneItem for a QDockWidget.
         """
-        raise NotImplementedError
+        raise NotImplementedError()
 
     def _get_dock_pane(self, pane):
         """ Returns the DockPane associated with a PaneItem.
