@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -60,7 +60,7 @@ class ViewSetStructureHandler(SetStructureHandler):
             control = window_layout._wx_get_view_control(view)
 
         else:
-            logger.warn("could not restore view [%s]", id)
+            logger.warning("could not restore view [%s]", id)
             control = None
 
         return control
